@@ -126,6 +126,23 @@ def artefacts(tmp_path):
             ],
             "qemu-armv7-kselftest-ipc.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-armv7",
+                "--tests",
+                "ltp-fs_perms_simple",
+                "--tests",
+                "ltp-fsx",
+                "--tests",
+                "ltp-nptl",
+                "--timeouts",
+                "ltp-fs_perms_simple=4",
+                "--timeouts",
+                "ltp-fsx=3",
+            ],
+            "qemu-armv7-ltp-mutliple-tests.yaml",
+        ),
         (
             [
                 "--device",
@@ -156,6 +173,10 @@ def artefacts(tmp_path):
             ["--device", "qemu-i386", "--tests", "kunit"],
             "qemu-i386-kunit.yaml",
         ),
+        (
+            ["--device", "qemu-i386", "--tests", "perf"],
+            "qemu-i386-perf.yaml",
+        ),
         (
             [
                 "--device",
